icsemantic.catalog.tests.base

Package platecom :: Package ontocatalog :: Package tests :: Module base |
[hide private]
[frames] | no frames]

# Module base

source code

Test setup for unit, integration and functional tests.

When we import PloneTestCase and then call setupPloneSite(), all of Plone's products are loaded, and a Plone site will be created. This happens at module level, which makes it faster to run each test, but slows down test runner startup.

Classes | [hide private]
| OntoCatalogTestCase We use this base class for all the tests in this package.
| OntoCatalogFunctionalTestCase We use this class for functional integration tests that use doctest syntax.

Functions | [hide private]
setup_icsemantic.catalog() | source code
add_test_thesaurus(portal) Fill the thesaurus local utility with some useful information | source code

Function Details | [hide private]

### setup_icsemantic.catalog() | source code
Decorators: `@onsetup`